#!/usr/bin/bash

RELEASEFILE=/etc/redos-release

function check_num {
    MAINVER=`cut -d "(" -f 1 < $RELEASEFILE | \
    sed -e "s/[^0-9.]//g" -e "s/$//g" | cut -d "." -f 1`

    echo $MAINVER | grep -q '[0-9]' && echo $MAINVER
}

function check_fullnum {
    MAINVER=`cut -d "(" -f 1 < $RELEASEFILE | \
    sed -e "s/[^0-9.]//g" -e "s/$//g"`

    echo $MAINVER | grep -q '[0-9]' && echo $MAINVER
}

function check_redos {
    grep -q "RED OS" $RELEASEFILE && echo $DISTNUM
}

function check_rhl {
    grep -q "Red Hat Linux" $RELEASEFILE && ! grep -q "Advanced" $RELEASEFILE && echo $DISTNUM
}

function check_rhel {
    egrep -q "(Enterprise|Advanced|CentOS)" $RELEASEFILE && echo $DISTNUM
}

function check_fedora {
    grep -q Fedora $RELEASEFILE && echo $DISTNUM
}

DISTNUM=`check_num`
DISTFULLNUM=`check_fullnum`
DISTREDOS=`check_redos`
DISTFC=`check_fedora`
DISTRHL=`check_rhl`
DISTRHEL=`check_rhel`
if [ -n "$DISTNUM" ]; then
    if [ -n "$DISTREDOS" ]; then
      if [ $DISTNUM -gt 7 ]; then
         echo $DISTNUM
         DISTNUM=$(echo ${DISTFULLNUM} | sed 's/\.//g')
      fi
    DISTTYPE=red
    elif [ -n "$DISTFC" ]; then
    DISTTYPE=fc
    elif [ -n "$DISTRHEL" ]; then
    DISTTYPE=el
    elif [ -n "$DISTRHL" ]; then
    DISTTYPE=rhl
    fi
fi
[ -n "$DISTTYPE" -a -n "$DISTNUM" ] && DISTTAG=".${DISTTYPE}${DISTNUM}"

case "$1" in
    --el) echo -n "$DISTRHEL" ;;
    --red) echo -n "$DISTREDOS" ;;
    --fc) echo -n "$DISTFC" ;;
    --rhl) echo -n "$DISTRHL" ;;
    --distnum) echo -n "$DISTNUM" ;;
    --disttype) echo -n "$DISTTYPE" ;;
    --help)
    printf "Usage: $0 [OPTIONS]\n"
    printf " Default mode is --dist. Possible options:\n"
    printf " --el\t\tfor RHEL version (if RHEL)\n"
    printf " --red\t\tfor RED OS version (if RED OS)\n"
    printf " --fc\t\tfor Fedora version (if Fedora)\n"
    printf " --rhl\t\tfor RHL version (if RHL)\n"
    printf " --dist\t\tfor distribution tag\n"
    printf " --distnum\tfor distribution number (major)\n"
    printf " --disttype\tfor distribution type\n" ;;
    *) echo -n "$DISTTAG" ;;
esac